package org.apache.bcel.generic;

import java.util.StringTokenizer;
import org.apache.bcel.Const;
import org.apache.bcel.classfile.Constant;
import org.apache.bcel.classfile.ConstantCP;
import org.apache.bcel.classfile.ConstantPool;
import org.apache.bcel.classfile.Utility;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/InvokeInstruction.class */
public abstract class InvokeInstruction extends FieldOrMethod implements ExceptionThrower, StackConsumer, StackProducer {
    /* JADX INFO: Access modifiers changed from: package-private */
    public InvokeInstruction() {
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public InvokeInstruction(short opcode, int index) {
        super(opcode, index);
    }

    @Override // org.apache.bcel.generic.Instruction, org.apache.bcel.generic.StackConsumer
    public int consumeStack(ConstantPoolGen cpg) {
        int sum;
        if (super.getOpcode() == 184 || super.getOpcode() == 186) {
            sum = 0;
        } else {
            sum = 1;
        }
        String signature = getSignature(cpg);
        return sum + Type.getArgumentTypesSize(signature);
    }

    public Type[] getArgumentTypes(ConstantPoolGen cpg) {
        return Type.getArgumentTypes(getSignature(cpg));
    }

    @Override // org.apache.bcel.generic.FieldOrMethod
    public String getClassName(ConstantPoolGen cpg) {
        ConstantPool cp = cpg.getConstantPool();
        ConstantCP cmr = cp.getConstant(super.getIndex());
        String className = cp.getConstantString(cmr.getClassIndex(), (byte) 7);
        return Utility.pathToPackage(className);
    }

    public String getMethodName(ConstantPoolGen cpg) {
        return getName(cpg);
    }

    public Type getReturnType(ConstantPoolGen cpg) {
        return Type.getReturnType(getSignature(cpg));
    }

    @Override // org.apache.bcel.generic.CPInstruction, org.apache.bcel.generic.TypedInstruction
    public Type getType(ConstantPoolGen cpg) {
        return getReturnType(cpg);
    }

    @Override // org.apache.bcel.generic.Instruction, org.apache.bcel.generic.StackProducer
    public int produceStack(ConstantPoolGen cpg) {
        String signature = getSignature(cpg);
        return Type.getReturnTypeSize(signature);
    }

    @Override // org.apache.bcel.generic.CPInstruction, org.apache.bcel.generic.Instruction
    public String toString(ConstantPool cp) {
        Constant c = cp.getConstant(super.getIndex());
        StringTokenizer tok = new StringTokenizer(cp.constantToString(c));
        String opcodeName = Const.getOpcodeName(super.getOpcode());
        StringBuilder sb = new StringBuilder(opcodeName);
        if (tok.hasMoreTokens()) {
            sb.append(" ");
            sb.append(tok.nextToken().replace('.', '/'));
            if (tok.hasMoreTokens()) {
                sb.append(tok.nextToken());
            }
        }
        return sb.toString();
    }
}
